@@ -105,7 +105,7 @@ class ABIBridge:
             _mgr= APIBridge(contract_address=self.contract_address)
         self.contract_address=contract_address or self.contract_address
         if self.api_mgr.contract_address != self.contract_address:
-            souce_code = derive_network(contract_address=self.contract_address,initial_network=self.api_mgr.rpc_mgr.name)
+            source_code = derive_network(contract_address=self.contract_address,initial_network=self.api_mgr.rpc_mgr.name)
             self.abi=source_code['source_code'][0]['ABI']
             self.rpc_js = source_code['network']
         self.contract_address = self.api_mgr.contract_address
@@ -117,7 +117,7 @@ class ABIBridge:
         :return: Contract bridge instance.
         """
         abi= abi or self.abi
-        contract_address = checksum(contract_address or self.contract_address)
+        contract_address = checksum(address=contract_address or self.contract_address)
         rpc_mgr = rpc_mgr or self.rpc_mgr
         if abi==None:
             self.abi = self.fetch_abi(contract_address)
